import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Pagination } from 'antd';
import { connect, history } from 'umi';
import { SearchOutlined, ClearOutlined, PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import { getCookie } from '@/utils/method';

import './Account.less';

import moment from 'moment';

const Account = (props: any) => {
  const { dispatch, Data, DataSave, DataSaveDetail, Result, loading } = props;
  const RA = (index: any, values: any) => {
    dispatch({ type: 'Account/RA', playload: { index: index, body: values } });
  };

  // 数据
  useEffect(() => {
    let obj = {
      leaderID: getCookie('id'),
    };
    RA(45, obj);
  }, [1]); //页面进来执行一次

  // 数据
  useEffect(() => {
    if (Data == null) {
      let obj = {
        leaderID: getCookie('id'),
      };
      RA(45, obj);
    }
  }, [Data]); //页面进来执行一次

  // 表单标识
  const [form] = Form.useForm();

  // 表头
  const columns = [
    {
      title: 'Account Name',
      dataIndex: 'tosUserName',
      key: 'userAccount',
    },
    {
      title: 'Grade',
      dataIndex: 'tosuserLevel',
      key: 'userLevel',
      render: (text: any) => (
        <span>
          {text == 5 || text == 0 ? '超级管理员' : ''}
          {text == 4 ? '一级管理员' : ''}
          {text == 3 ? '二级管理员' : ''}
          {text == 2 ? '三级管理员' : ''}
          {text == 1 ? '一级管理员' : ''}
        </span>
      ),
    },

    {
      title: 'Status',
      dataIndex: 'userStatus',
      key: 'userStatus',
      render: (text: any) => <span>{text == 0 ? '启用' : '禁用'}</span>,
    },
    {
      title: 'Created By',
      dataIndex: 'tosUserServiceCell',
      key: 'createAccount',
    },
    {
      title: 'Creation Time',
      dataIndex: 'createTime',
      key: 'createTime',
      render: (text: any) => {
        return moment(text.time).format('YYYY-MM-DD');
      },
    },

    {
      title: 'Actions',
      dataIndex: 'action',
      key: 'action',
      render: (record: any) => (
        <span>
          <Button
            type="link"
            onClick={() => {
              edit(record);
            }}
          >
            Edit
          </Button>
          <Button
            type="link"
            onClick={() => {
              lockS(record);
            }}
          >
            {record.userStatus == 1 ? 'Lock' : 'Unlock'}
          </Button>
          {/*{record.userID == 1||record.userID == this.props.currentUser.userid?'':
          <Button style={{background: 'transparent', border: 0, color: '#1890FF'}}
                  onClick={() => this.changeStatus(record)}>
            {record.userStatus == 1 ? "lock" : "unlock"}</Button>}*/}
        </span>
      ),
    },
  ];

  const edit = (item: any) => {
    history.push('./account/edit');
  };

  const lockS = (item: any) => {};

  return (
    <>
      <div className="contop">
        <Form
          autoComplete="off"
          layout="inline"
          form={form}
          name="contract"
          // onFinish={onFinishContract}
        >
          <Form.Item name="username">
            <Input allowClear placeholder="Account Name" />
          </Form.Item>
          <Form.Item name="creator">
            <Input allowClear placeholder="Account Creator" />
          </Form.Item>
          <Form.Item>
            <Button type="primary" htmlType="submit" icon={<SearchOutlined />} loading={loading}>
              Search{' '}
            </Button>
            <Button
              htmlType="button"
              // onClick={onReset}
              style={{ marginLeft: '15px' }}
              icon={<ClearOutlined />}
              loading={loading}
            >
              {' '}
              Reset
            </Button>
          </Form.Item>
        </Form>
      </div>

      <div className="contop contop2">
        <ProTable
          // request={requestHeadl}
          rowKey={'id'}
          dataSource={Data ? Data.rows : null}
          columns={columns}
          pagination={false} // 隐藏默认分页
          search={false}
          loading={loading}
          toolBarRender={() => [
            <Button
              type="primary"
              loading={loading}
              icon={<PlusOutlined />}
              onClick={() => {
                // Jump(0, 'Add');
              }}
            >
              Add Account
            </Button>,
          ]}
          options={{
            density: false,
            fullScreen: false,
            reload: () => {
              edit;
            },
            setting: false,
          }}
          headerTitle="Account list"
          // pagination={{ defaultCurrent: 1, total: Data.totalRow }}
        />

        <div className="pages">
          <Pagination
            // onShowSizeChange={pageSizeHandler}
            // current={Data.total}
            total={Data ? Data.total : 0}
            pageSize={Data ? Data.total : 0}
          />
        </div>
      </div>
    </>
  );
};

const AccountProps = (styte: any) => {
  console.log(styte);
  const { Data, DataSave, DataSaveDetail, Result } = styte.Account;
  const loading = styte.loading.models.Account || false;
  return {
    Data,
    DataSave,
    DataSaveDetail,
    Result,
    loading,
  };
};

export default connect(AccountProps)(Account);
