import React, { useState, useEffect, useRef } from 'react';

import styles from './index.less';
import { Form, Input, Spin, Table, Space, Button, message } from 'antd';
import { LoadingOutlined } from '@ant-design/icons';

import { urlEncode, filterObj, filterObjbyTg, RA } from '@/utils/method';

import { Link, useIntl, connect, Dispatch, history } from 'umi';

import TitleSearch from '../../../components/TitleSearch/TitleSearch';
import { TosSecurityGuarderGet } from '@/services/tos';

const module = 'User';
// 服务范围数据
let options: Array<[number, string]> = [];

// 筛选参数
let readyData: any = {
  pageNum: 1,
  serviceCommunityList: [],
  serviceScope: '',
  providerName: '',
};
// 节流阀
let flag: boolean = false;

const ServiceProviderManagement = (props: any) => {
  const permissionArr = JSON.parse(localStorage.getItem('permission') || '');

  const [loading, setLoading] = useState(false);

  const { dispatch, location, Data, CommunityList, DataServices } = props;

  const SaveChooseData = (values: any) => {
    dispatch({ type: 'ServiceProvider/SaveChooseData', playload: values });
  };

  const goToDetail = (values: any, e: any) => {
    if (permissionArr.indexOf('6') < 0) {
      message.error('No Permissions!!!', 3);
      return;
    }
    values.serviceScope = options[values.serviceScopeList[0]][1];
    SaveChooseData(values);
    if (values.serviceScopeList[0] === '0') {
      history.push(location.pathname + '/Detail');
    } else if (values.serviceScopeList[0] === '1') {
      history.push(location.pathname + '/AccoutingDetail');
    } else {
      history.push('/404');
    }
  };
  const goToEdit = (values: any, e: any) => {
    if (permissionArr.indexOf('7') < 0) {
      message.error('No Permissions!!!', 3);
      return;
    }
    SaveChooseData(values);
    history.push(location.pathname + '/Edit');
    // if (values.serviceScopeList[0] === '0') {
    // } else if (values.serviceScopeList[0] === '1') {
    //   history.push(location.pathname + '/AccoutingEdit');
    // } else {
    //   history.push('/404');
    // }
  };
  const goToCreate = () => {
    if (permissionArr.indexOf('8') < 0) {
      message.error('No Permissions!!!', 3);
      return;
    }
    SaveChooseData(null);
    history.push(location.pathname + '/Edit');
  };
  const goToServices = () => {
    history.push(location.pathname + '/Services');
  };

  const columns = [
    { title: 'Service Provider', dataIndex: 'providerName' },
    { title: 'contact Name', dataIndex: 'contactName' },

    {
      title: 'Contacts',
      dataIndex: 'contactPhone',
    },
    {
      title: 'Services Available',
      dataIndex: 'serviceScopeList',
      render: (text: any, record: any) => {
        if (options.length > 0) {
          return options[text[0]][1];
        }
      },
    },
    { title: 'Account Status', dataIndex: 'enable' },
    {
      title: 'Actions',
      render: (text: any, record: any) => (
        <Space size="middle">
          <a onClick={goToDetail.bind(this, record)}>Detail</a>
          <a
            disabled={record.enable == 'Deregistered' ? true : false}
            onClick={goToEdit.bind(this, record)}
          >
            Edit
          </a>
        </Space>
      ),
    },
  ];

  // 拿取服务商列表
  useEffect(() => {
    RA(43, {}, module, dispatch);
  }, []);

  // 处理服务商数据
  useEffect(() => {
    if (DataServices) {
      console.log(DataServices);
      options = DataServices.data.rows.map((v: any) => {
        return [v.serviceCode, v.serviceName];
      });
    }
  }, [DataServices]);

  // 请求
  const TosTosServiceProviderGet = () => {
    if (readyData.serviceCommunityList.length === 0) {
      readyData.serviceCommunityList = CommunityList;
    }
    dispatch({
      type: 'ServiceProvider/TosTosServiceProviderGet',
      playload: { ...readyData },
    });
  };

  // 监听路由url
  useEffect(() => {
    if (location.query) {
      readyData = {
        ...readyData,
        ...location.query,
      };
    }

    if (CommunityList && flag === false) {
      flag = true;
      setLoading(true);
      TosTosServiceProviderGet();
    }
  }, [location]);

  // 监听小区数据
  useEffect(() => {
    if (CommunityList && flag === false) {
      flag = true;
      setLoading(true);
      TosTosServiceProviderGet();
    }
  }, [CommunityList]);

  // 数据核查
  useEffect(() => {
    if (Data != null) {
      flag = false;
      setLoading(false);
    }
  }, [Data]);

  //页面搜索
  const CallBackTitleSearch = (comment: any) => {
    readyData.serviceCommunityList = comment.serviceCommunityList;
    if (comment.status == undefined) {
      comment.status = '';
    }
    console.log(comment);
    // if (comment.status) {

    // }

    history.push(
      location.pathname +
        urlEncode(
          filterObj({
            providerName: comment.providerName,
            serviceScope: comment.status,
            pageNum: 1,
          }),
        ),
    );
  };

  // 切换页码
  const pageChange = (values: any) => {
    let tmp = filterObjbyTg(location.query, ['providerName', 'serviceScope']);
    tmp['pageNum'] = values.current;
    history.push(location.pathname + urlEncode(tmp));
  };

  // 数据处理
  const dataSource = (values: any) => {
    let tmp = values;
    for (let items in tmp) {
      switch (tmp[items].enable) {
        case 0:
          tmp[items].enable = 'Normal';
          break;
        case 1:
          tmp[items].enable = 'Deregistered';
          break;
        case 2:
          break;
      }
    }
    return tmp;
  };

  return (
    <div className={styles.base}>
      {/* 头部组件 */}
      <TitleSearch
        listkey={['providerName']}
        list={['Service Provider']}
        status={[
          {
            name: ['status', 'Services'],
            data: [...options],
          },
        ]}
        community={'serviceCommunityList'}
        onSubmit={CallBackTitleSearch}
        defaultValue={{
          providerName: readyData.providerName,
          status: readyData.serviceScope
            ? parseInt(readyData.serviceScope) === 0
              ? 'SecurutyGuard'
              : 'Accountant'
            : null,
        }}
        checklist={
          readyData.serviceCommunityList.length !== 0 ? readyData.serviceCommunityList : null
        }
      />

      {/* 内容组件 */}
      <div className={styles.box2}>
        <button className={styles.buttonAdd2} onClick={goToServices}>
          Avail Services
        </button>
        <button className={styles.buttonAdd} onClick={goToCreate}>
          Create New
        </button>
      </div>

      {/* 列表组件 */}
      <Table
        rowKey={'id'}
        style={{ marginTop: 16 }}
        loading={loading}
        columns={columns}
        dataSource={Data != null ? dataSource(Data.rows) : []}
        pagination={
          Data != null
            ? {
                current: parseInt(readyData.pageNum),
                total: Data.page.totalRow,
                showSizeChanger: false,
                pageSize: Data.page.curPageSize,
              }
            : {}
        }
        onChange={pageChange}
      />
    </div>
  );
};

function mapStateToProps(state: any) {
  const { Data } = state.ServiceProvider;
  const { DataProvider, DataServices } = state.User;
  const { CommunityList } = state.Init;
  return {
    Data,
    DataProvider,
    CommunityList,
    DataServices,
  };
}

export default connect(mapStateToProps)(ServiceProviderManagement);
